#
# spec file for package step-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define configdir %{_sysconfdir}/step
%define certsdir  %{_sysconfdir}/step/certs
%define services  cert-renewer.target ssh-cert-renewer.timer ssh-cert-renewer@.timer cert-renewer@.timer ssh-cert-renewer.service ssh-cert-renewer@.service cert-renewer@.service
%define pkg_name cli
%define pkg_version %{version}
Name:           step-cli
Version:        0.28.2
Release:        1.2
Summary:        Zero trust swiss army knife for working with X509, OAuth, JWT, OATH OTP, etc
License:        Apache-2.0
URL:            https://smallstep.com/cli
# https://github.com/smallstep/cli/releases
Source:         https://github.com/smallstep/cli/archive/refs/tags/v%{pkg_version}.tar.gz#/%{pkg_name}-%{pkg_version}.tar.gz
Source1:        vendor.tar.xz
Source2:        series
Patch0:         more-units.patch
Patch1:         add-missing-targets.patch
BuildRequires:  fish
BuildRequires:  golang-packaging
BuildRequires:  pkgconfig
BuildRequires:  zsh
BuildRequires:  golang(API) >= 1.19
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(systemd)
Conflicts:      step
%{?systemd_ordering}

%description
A zero trust swiss army knife for working with X509, OAuth, JWT, OATH OTP, etc.

%package bash-completion
Summary:        Bash Completion for %{name}
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash completion script for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
fish shell completions for %{name}.

%package zsh-completion
Summary:        ZSH completion for %{name}
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
zsh shell completions for %{name}.

%prep
%autosetup -p1 -n %{pkg_name}-%{pkg_version} -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build -buildmode=pie -mod=vendor -ldflags="-w -X 'main.Version=%{version}' -X 'main.BuildTime=${BUILD_DATE}'" ./cmd/...
for shell in bash zsh fish ; do
./step completion ${shell} > autocomplete/${shell}_autocomplete
done

%install
install -D -m 0755 step                           %{buildroot}%{_bindir}/step
# shell completions
install -D -m 0644 autocomplete/bash_autocomplete   %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -D -m 0644 autocomplete/zsh_autocomplete    %{buildroot}%{_sysconfdir}/zsh_completion.d/%{name}
install -D -m 0644 autocomplete/fish_autocomplete   %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish

for unit in %{services} ; do
install -D -m 0644 systemd/${unit} %{buildroot}%{_unitdir}/${unit}
done

install -D -d -m 0711 %{buildroot}%{configdir}/{certs,config}

%check
./step --version | grep %{version}

%pre
%service_add_pre %{services}

%post
%service_add_post %{services}

%preun
%service_del_preun %{services}

%postun
%service_del_postun %{services}

%files
%doc README.md
%license LICENSE
%{_bindir}/step*
%{_unitdir}/ssh-cert-renewer.service
%{_unitdir}/ssh-cert-renewer.timer
%{_unitdir}/ssh-cert-renewer@.service
%{_unitdir}/ssh-cert-renewer@.timer
%{_unitdir}/cert-renewer@.service
%{_unitdir}/cert-renewer@.timer
%{_unitdir}/cert-renewer.target
%config(noreplace) %attr(-,root,root) %{configdir}
%config(noreplace) %attr(640,root,root) %ghost %{configdir}/config/defaults.json

%files bash-completion
%license LICENSE
%{_datadir}/bash-completion/completions/%{name}

%files zsh-completion
%license LICENSE
%config %{_sysconfdir}/zsh_completion.d/%{name}

%files fish-completion
%license LICENSE
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%changelog
* Wed Nov 20 2024 Marcus Rueckert <mrueckert@suse.de>
- update to 0.28.2
  https://github.com/smallstep/cli/releases/tag/v0.28.2
* Wed Nov 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- use download_files service to download the tarball
* Wed Nov 20 2024 Marcus Rueckert <mrueckert@suse.de>
- update to 0.28.1
  https://github.com/smallstep/cli/releases/tag/v0.28.1
* Wed Oct 30 2024 Marcus Rueckert <mrueckert@suse.de>
- update to 0.28.0
  https://github.com/smallstep/cli/releases/tag/v0.28.0
* Sat Oct 26 2024 Marcus Rueckert <mrueckert@suse.de>
- add back the service file for vendoring modules
* Thu Oct 17 2024 Marcus Rueckert <mrueckert@suse.de>
- update to 0.27.5
  https://github.com/smallstep/cli/releases/tag/v0.27.5
* Fri Sep 13 2024 Marcus Rueckert <mrueckert@suse.de>
- update to 0.27.4
  https://github.com/smallstep/cli/releases/tag/v0.27.4
* Thu Jul 18 2024 Marcus Rueckert <mrueckert@suse.de>
- update to 0.27.2
  https://github.com/smallstep/cli/releases/tag/v0.27.2
* Fri Jul 12 2024 Marcus Rueckert <mrueckert@suse.de>
- update to 0.27.1
  https://github.com/smallstep/cli/releases/tag/v0.27.1
  https://github.com/smallstep/cli/releases/tag/v0.27.0
* Thu Jun 13 2024 Marcus Rueckert <mrueckert@suse.de>
- update to 0.26.2
  https://github.com/smallstep/cli/releases/tag/v0.26.2
* Tue Apr 23 2024 Marcus Rueckert <mrueckert@suse.de>
- update to 0.26.1
  https://github.com/smallstep/cli/releases/tag/v0.26.1
* Fri Mar 29 2024 Marcus Rueckert <mrueckert@suse.de>
- update to 0.26.0
  https://github.com/smallstep/cli/releases/tag/v0.26.0
* Fri Jan 19 2024 Marcus Rueckert <mrueckert@suse.de>
- update to 0.25.2
  https://github.com/smallstep/cli/releases/tag/v0.25.2
* Wed Nov 29 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 0.25.1
  https://github.com/smallstep/cli/releases/tag/v0.25.1
* Wed Sep 27 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 0.25.0
  https://github.com/smallstep/cli/releases/tag/v0.25.0
* Thu May 11 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 0.24.4
  https://github.com/smallstep/cli/releases/tag/v0.24.4
* Mon Apr 17 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 0.24.3
  https://github.com/smallstep/cli/releases/tag/v0.24.3
* Fri Apr 14 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 0.24.2
  https://github.com/smallstep/cli/releases/tag/v0.24.2
* Fri Apr 14 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 0.24.1
  https://github.com/smallstep/cli/releases/tag/v0.24.1
  https://github.com/smallstep/cli/releases/tag/v0.24.0
* Thu Apr  6 2023 Marcus Rueckert <mrueckert@suse.de>
- bump requires for go as 1.17 is nolonger sufficient
* Sat Mar 11 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 0.23.4
  https://github.com/smallstep/cli/releases/tag/v0.23.4
* Wed Mar  1 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 0.23.3
  https://github.com/smallstep/cli/releases/tag/v0.23.3
* Tue Feb 14 2023 Marcus Rueckert <mrueckert@suse.de>
- move salt related tools into its own package
* Mon Feb 13 2023 Marcus Rueckert <mrueckert@suse.de>
- Added step-ssl-merge-certs-for-salt helper script
* Tue Feb  7 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 0.23.2
  https://github.com/smallstep/cli/releases/tag/v0.23.2
* Mon Jan 23 2023 Marcus Rueckert <mrueckert@suse.de>
- make our helper scripts expire certs after 14 days
  TODO: this should be configurable
* Wed Jan 11 2023 Marcus Rueckert <mrueckert@suse.de>
- update to 0.23.1
  https://github.com/smallstep/cli/releases/tag/v0.23.1
* Tue Dec 13 2022 Marcus Rueckert <mrueckert@suse.de>
- Add zsh as requires to the completion package
* Wed Nov 30 2022 Marcus Rueckert <mrueckert@suse.de>
- Add 2 wrappers to help salt with deciding if certs need renewal
* Sat Nov 12 2022 Marcus Rueckert <mrueckert@suse.de>
- update to 0.23.0
  https://github.com/smallstep/cli/releases/tag/v0.23.0
* Fri Aug 26 2022 Marcus Rueckert <mrueckert@suse.de>
- update to 0.22.0
  https://github.com/smallstep/cli/releases/tag/v0.22.0
- drop merged chunks from more-units.patch
- added add-missing-targets.patch:
  ssh service had no target
* Thu Jul  7 2022 Marcus Rueckert <mrueckert@suse.de>
- update to 0.21.0
  https://github.com/smallstep/cli/releases/tag/v0.21.0
* Fri May 27 2022 Marcus Rueckert <mrueckert@suse.de>
- update to 0.20.0
  https://github.com/smallstep/cli/releases/tag/v0.20.0
* Thu Apr 21 2022 Marcus Rueckert <mrueckert@suse.de>
- update to 0.19.0
  https://github.com/smallstep/cli/releases/tag/v0.19.0
* Thu Mar 24 2022 Marcus Rueckert <mrueckert@suse.de>
- Adds more-units.patch:
  - Add unit files for renewing ssh certificates
  - Add target files for both instantiated services
* Wed Mar 23 2022 Marcus Rueckert <mrueckert@suse.de>
- we also need the /etc/step/config/ directory
* Thu Mar  3 2022 Marcus Rueckert <mrueckert@suse.de>
- also install the renewer service
- replace packageand with the newer (pkg1 and pkg2) syntax
* Wed Mar  2 2022 Marcus Rueckert <mrueckert@suse.de>
- update to 0.18.2
  https://github.com/smallstep/cli/releases/tag/v0.18.2
* Fri Feb  4 2022 Marcus Rueckert <mrueckert@suse.de>
- update to 0.18.1
  https://github.com/smallstep/cli/releases/tag/v0.18.1
* Thu Nov 18 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.18.0
  https://github.com/smallstep/cli/releases/tag/v0.18.0
* Thu Oct 21 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.17.7
  https://github.com/smallstep/cli/releases/tag/v0.17.7
* Fri Oct  1 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.17.6
  https://github.com/smallstep/cli/releases/tag/v0.17.6
* Wed Sep 29 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.17.5
  https://github.com/smallstep/cli/releases/tag/v0.17.5
* Sat Sep 25 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.17.4
  https://github.com/smallstep/cli/releases/tag/v0.17.4
* Sat Sep 25 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.17.3
  https://github.com/smallstep/cli/releases/tag/v0.17.3
* Tue Aug 31 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.17.2
  https://github.com/smallstep/cli/releases/tag/v0.17.2
* Fri Aug 27 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.17.1
  https://github.com/smallstep/cli/releases/tag/v0.17.1
* Thu Aug 26 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.17.0
  https://github.com/smallstep/cli/releases/tag/v0.17.0
* Mon Jul 12 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.16.1
  https://github.com/smallstep/cli/releases/tag/v0.16.1
* Tue Jul  6 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.15.17
  https://github.com/smallstep/cli/releases/tag/v0.15.17
* Fri Apr 16 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.15.16
  https://github.com/smallstep/cli/releases/tag/v0.15.16
* Thu Apr 15 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.15.15
  https://github.com/smallstep/cli/releases/tag/v0.15.15
* Thu Apr 15 2021 Marcus Rueckert <mrueckert@suse.de>
- zsh-completion should also require the base package. bash
  completion already did.
* Sat Mar 27 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.15.14
  https://github.com/smallstep/cli/releases/tag/v0.15.14
* Fri Mar 12 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.15.13
  https://github.com/smallstep/cli/releases/tag/v0.15.9
  https://github.com/smallstep/cli/releases/tag/v0.15.10
  https://github.com/smallstep/cli/releases/tag/v0.15.11
  https://github.com/smallstep/cli/releases/tag/v0.15.12
  https://github.com/smallstep/cli/releases/tag/v0.15.13
* Tue Mar  9 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.15.8
  https://github.com/smallstep/cli/releases/tag/v0.15.8
* Fri Feb 19 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 0.15.7
  https://github.com/smallstep/cli/releases/tag/v0.15.3
  https://github.com/smallstep/cli/releases/tag/v0.15.4
  https://github.com/smallstep/cli/releases/tag/v0.15.5
  https://github.com/smallstep/cli/releases/tag/v0.15.6
  https://github.com/smallstep/cli/releases/tag/v0.15.7
* Sun Nov 29 2020 Marcus Rueckert <mrueckert@suse.de>
- switching to go 1.15
* Mon Aug 31 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.15.2
  https://github.com/smallstep/cli/releases/tag/v0.15.2
* Mon Aug 31 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.15.1
  https://github.com/smallstep/cli/releases/tag/v0.15.1
* Mon Aug 17 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.15.0
  https://github.com/smallstep/cli/releases/tag/v0.15.0
* Thu Jul  2 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.14.6
  https://github.com/smallstep/cli/releases/tag/v0.14.6
* Thu Jul  2 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.14.5
  https://github.com/smallstep/cli/releases/tag/v0.14.5
* Tue May 19 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.14.4
  https://github.com/smallstep/cli/releases/tag/v0.14.4
* Mon May  4 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.14.4~rc1
  https://github.com/smallstep/cli/releases/tag/v0.14.4-rc.1
* Fri May  1 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.14.3
  https://github.com/smallstep/cli/releases/tag/v0.14.3
* Wed Apr 22 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.14.3~rc1
  https://github.com/smallstep/cli/releases/tag/v0.14.3-rc.1
* Fri Apr 10 2020 Marcus Rueckert <mrueckert@suse.de>
- we no longer need golang-github-golang-dep
* Fri Apr 10 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.14.2
  https://github.com/smallstep/cli/releases/tag/v0.14.1
  https://github.com/smallstep/cli/releases/tag/v0.14.2
* Thu Apr  9 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.14.0
  https://github.com/smallstep/cli/releases/tag/v0.14.0
* Tue Apr  7 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.14.0~rc5
  https://github.com/smallstep/cli/releases/tag/v0.14.0-rc.5
* Thu Mar 19 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.14.0~rc4
  https://github.com/smallstep/cli/releases/tag/v0.14.0-rc.4
* Mon Mar  9 2020 Martin Hauke <mardnh@gmx.de>
- Supplement against bash-completion, not bash
* Thu Feb 27 2020 Marcus Rueckert <mrueckert@suse.de>
- allow go 1.14
* Sat Feb  8 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 0.14.0~rc3
  https://github.com/smallstep/cli/releases/tag/v0.14.0-rc.2
  https://github.com/smallstep/cli/releases/tag/v0.14.0-rc.3
* Sun Nov 17 2019 Marcus Rueckert <mrueckert@suse.de>
- no longer rename the binary but conflict on the package which
  provides the other /usr/bin/step
* Fri Nov 15 2019 Martin Hauke <mardnh@gmx.de>
- Add subpackages for bash- and zsh-completion
- Correct license (BSD-3-Clause -> Apache-2.0)
* Fri Nov  1 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 0.14.0~rc1
  https://github.com/smallstep/cli/releases/tag/v0.14.0-rc.1
* Mon Sep 30 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 0.13.3
  https://github.com/smallstep/cli/releases/tag/v0.13.3
* Mon Sep 30 2019 Marcus Rueckert <mrueckert@suse.de>
- fix version string
* Mon Sep 30 2019 Marcus Rueckert <mrueckert@suse.de>
- initial package
